summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-09-18 21:49:14 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-09-18 21:49:14 +0000
commit0014114cd273fb4485196bd02a58aac5adad3d67 (patch)
tree8542b167379fa66557bc866f01f10fa16a876e68
parenta6c474508ee54308e43fbf67644ab2f78fc1ad83 (diff)
downloadtdebase-0014114cd273fb4485196bd02a58aac5adad3d67.tar.gz
tdebase-0014114cd273fb4485196bd02a58aac5adad3d67.zip
Bugfixes
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebase@1176854 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
-rw-r--r--Mainpage.dox6
-rw-r--r--kdesktop/kdesktop.kcfg2
-rw-r--r--kicker/kicker/core/containerarealayout.cpp2
-rw-r--r--kpersonalizer/kcountrypage.cpp4
-rw-r--r--kpersonalizer/kospagedlg.ui2
-rw-r--r--kpersonalizer/pics/step3.pngbin70284 -> 48972 bytes
-rw-r--r--startkde9
7 files changed, 15 insertions, 10 deletions
diff --git a/Mainpage.dox b/Mainpage.dox
index 044568fbe..a1e9e43d8 100644
--- a/Mainpage.dox
+++ b/Mainpage.dox
@@ -1,8 +1,8 @@
/** @mainpage
-* KDE Base API Dox.
+* Trinity Base API Dox.
*
-* KDEBase is the SVN module with the "basic applications" needed
-* for KDE. These include startkde (a shell script to start the whole
+* kdebase is the SVN module with the "basic applications" needed
+* for Trinity. These include startkde (a shell script to start the whole
* desktop), kdesktop (the desktop), konqueror (the browser and file-
* manager) and lots of other things. Nearly none of it has dox.
*
diff --git a/kdesktop/kdesktop.kcfg b/kdesktop/kdesktop.kcfg
index 2f5d730f3..a2f23dfaf 100644
--- a/kdesktop/kdesktop.kcfg
+++ b/kdesktop/kdesktop.kcfg
@@ -132,7 +132,7 @@
<whatsthis></whatsthis>
</entry>
<entry key="ShadowEnabled" type="Bool">
- <default>false</default>
+ <default>true</default>
<label>Enable text shadow</label>
<whatsthis>Check here to enable a shadow outline around the desktop font. This also improves the readability of the desktop text against backgrounds of a similar color.</whatsthis>
</entry>
diff --git a/kicker/kicker/core/containerarealayout.cpp b/kicker/kicker/core/containerarealayout.cpp
index 12a09c8e6..4ae63077e 100644
--- a/kicker/kicker/core/containerarealayout.cpp
+++ b/kicker/kicker/core/containerarealayout.cpp
@@ -386,7 +386,7 @@ TQWidget* ContainerAreaLayout::widgetAt(int index) const
TQSize ContainerAreaLayout::sizeHint() const
{
- const int size = KickerLib::sizeValue(KPanelExtension::SizeNormal);
+ const int size = KickerLib::sizeValue(KPanelExtension::SizeSmall);
if (orientation() == Horizontal)
{
diff --git a/kpersonalizer/kospagedlg.ui b/kpersonalizer/kospagedlg.ui
index adf084844..e4c5fd4b3 100644
--- a/kpersonalizer/kospagedlg.ui
+++ b/kpersonalizer/kospagedlg.ui
@@ -76,7 +76,7 @@
<cstring>rb_kde</cstring>
</property>
<property name="text">
- <string>Trinity (TM)</string>
+ <string>KDE (TM)</string>
</property>
<property name="checked">
<bool>true</bool>
diff --git a/kpersonalizer/pics/step3.png b/kpersonalizer/pics/step3.png
index df9741f38..763d246f8 100644
--- a/kpersonalizer/pics/step3.png
+++ b/kpersonalizer/pics/step3.png
Binary files differ
diff --git a/startkde b/startkde
index dd7cff485..a05084c92 100644
--- a/startkde
+++ b/startkde
@@ -163,8 +163,8 @@ fi
test -n "$KDEHOME" && kdehome=`echo "$KDEHOME" | sed "s,^~/,$HOME/,"`
echo "[startkde] kdehome: $kdehome" 1>&2
-# Is this a GNOME/GDM variable? Probably does not cause any harm in
-# any system not looking for the variable.
+# Allow interested applications, such as the Plasma control wrapper,
+# to know that this is a Trinity desktop and not a KDE one.
export DESKTOP_SESSION=kde3
# Please see kstartupconfig source for usage.
@@ -381,8 +381,13 @@ if test -r "$kde_fontpaths" ; then
IFS=$savifs
fi
+if [ -n "$KDEDIR" ]; then
+ export KDEDIR=`echo "$KDEDIRS" | sed -e 's/:.*//'`
+fi
+
echo "[startkde] KDEDIR: $KDEDIR" 1>&2
echo "[startkde] KDEDIRS: $KDEDIRS" 1>&2
+
if test -n "$KDEDIRS"; then
kdedirs_first=`echo "$KDEDIRS" | sed -e 's/:.*//'`
sys_odir=$kdedirs_first/share/fonts/override
diff --git a/kpersonalizer/kcountrypage.cpp b/kpersonalizer/kcountrypage.cpp
index ee8f44b87..4e30c7363 100644
--- a/kpersonalizer/kcountrypage.cpp
+++ b/kpersonalizer/kcountrypage.cpp
@@ -44,8 +44,8 @@ KCountryPage::KCountryPage(TQWidget *parent, const char *name ) : KCountryPageDl
b_savedLanguageChanged = false;
b_startedLanguageChanged = false;
- // set appropriate KDE version (kapplication.h)
- txt_welcome->setText(i18n("<h3>Welcome to KDE %1</h3>").arg(KDE_VERSION_STRING));
+ // set appropriate Trinity version (kapplication.h)
+ txt_welcome->setText(i18n("<h3>Welcome to Trinity %1</h3>").arg(KDE_VERSION_STRING));
flang = new KFindLanguage();